# WeightsToUseEnum

* `accepted_weights` - Accepted weights * `dispatched_weights` - Dispatched weights

## Enum

* `ACCEPTED_WEIGHTS` (value: `'accepted_weights'`)

* `DISPATCHED_WEIGHTS` (value: `'dispatched_weights'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


